YARP 2.0.4 (2006-07-05)                                                {#v2_0_4}
=======================

Contributors
------------

This is a list of people that contributed to this release (generated from the
git history using `git shortlog -ens --no-merges v2.0.4`):

```
   448	Paul Fitzpatrick <paulfitz@alum.mit.edu>
    55	Lorenzo Natale <lorenzo.natale@iit.it>
    34	YARP Developers <yarp0-devel@lists.sourceforge.net>
    24	Giorgio Metta <giorgio.metta@iit.it>
     1	Matteo Brunettini <matteo.brunettini@iit.it>
     1	Michael Bucko <m.c.bucko@gmail.com>
```
